@@ -59,7 +59,7 @@ from pyms_nist_search.reference_data import ReferenceData  # noqa: F401
 from pyms_nist_search.search_result import SearchResult  # noqa: F401
 
 # this package
-from ._core import *  # type: ignore  # noqa: F401
+from ._core import *  # noqa: F401
 
 if sys.platform == "win32":
 	# this package
@@ -73,7 +73,7 @@ name: str = "PyMassSpec NIST Search"
 __author__: str = "Dominic Davis-Foster"
 __license__: str = "LGPLv3+"
 __maintainer_email__: str = "dominic@davis-foster.co.uk"
-__version__: str = "0.5.0"
+__version__: str = "0.8.0"
 
 __copyright__: str = "2020 Dominic Davis-Foster"
 __email__: str = "dominic@davis-foster.co.uk"
